==> vice_3.5.0.dfsg.orig.tar.xz: vice-3.5.0.dfsg/src/arch/gtk3/uidata.h <==
/** \file   uidata.h
 * \brief   GTK3 binary resources handling - header
 *
 * \author  Bas Wassink <b.wassink@ziggo.nl>
 */

/*
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 */

#ifndef VICE_UIDATA_H
#define VICE_UIDATA_H

#include <gtk/gtk.h>

/** \brief  Root namespace of the GResouce files
 *
 * The GResource handling requires setting a namespace for the files, which
 * is similar to the argument to gtk_application_new(), basically inverting
 * a URL's components.
 *
 * In this case, I have used vice.pokefinder.org as our website.
 */
#define UIDATA_ROOT_PATH    "/org/pokefinder/vice"


int                 uidata_init(void);
void                uidata_shutdown(void);

GdkPixbuf *         uidata_get_pixbuf(const char *name);
GdkPixbuf *         uidata_get_pixbuf_at_scale(const char *name, int width, int height, gboolean preserve_aspect_ratio);
#if 0
GdkPixbufAnimation *uidata_get_pixbuf_animated(const char *name, gboolean loop);
#endif
GBytes *            uidata_get_bytes(const char *name);

#endif

==> vice_3.7.1+dfsg1.orig.tar.xz: vice-3.7.1+dfsg/src/arch/gtk3/uidata.h <==
/** \file   uidata.h
 * \brief   GTK3 binary resources handling - header
 *
 * \author  Bas Wassink <b.wassink@ziggo.nl>
 */

/*
 * This file is part of VICE, the Versatile Commodore Emulator.
 * See README for copyright notice.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
 *  02111-1307  USA.
 */

#ifndef VICE_UIDATA_H
#define VICE_UIDATA_H

#include <gtk/gtk.h>

/** \brief  Root namespace of the GResouce files
 *
 * The GResource handling requires setting a namespace for the files, which
 * is similar to the argument to gtk_application_new(), basically inverting
 * a URL's components.
 *
 * In this case, I have used vice.pokefinder.org as our website.
 */
#define UIDATA_ROOT_PATH    "/org/pokefinder/vice"

/** \brief  Name of the GResource file
 */
#define UIDATA_GRESOURCE_FILE   "vice.gresource"


gboolean uidata_init(void);
void uidata_shutdown(void);
GdkPixbuf *uidata_get_pixbuf(const gchar *name);
GdkPixbuf *uidata_get_pixbuf_at_scale(const gchar *name,
                                      gint width,
                                      gint height,
                                      gboolean preserve_aspect_ratio);
GBytes *uidata_get_bytes(const gchar *name);

#endif
